@@ -21,6 +21,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
+#include <ctype.h>
 #include <time.h>
 
 #ifndef WIN32
@@ -57,6 +58,7 @@ static char *logdir = NULL;
 void
 generate_filename(const char *dirname, const char *prefix, char *filename, size_t filenamelen)
 {
+	const char *exename = GetExeProgramName();
 #ifdef	WIN32
 	int	pid;
 
@@ -74,6 +76,8 @@ generate_filename(const char *dirname, const char *prefix, char *filename, size_
 	snprintf(filename, filenamelen, "%s%s", dirname, DIRSEPARATOR);
 	if (prefix != 0)
 		strlcat(filename, prefix, filenamelen);
+	if (exename[0])
+		snprintfcat(filename, filenamelen, "%s_", exename);
 #ifndef WIN32
 	if (ptr)
 		strlcat(filename, ptr->pw_name, filenamelen);
@@ -102,6 +106,59 @@ generate_homefile(const char *prefix, char *filename, size_t filenamelen)
 	return;
 }
 
+#ifdef  WIN32
+static  char    exename[_MAX_FNAME];
+#elif   defined MAXNAMELEN
+static  char    exename[MAXNAMELEN];
+#else
+static  char    exename[256];
+#endif
+
+const char *GetExeProgramName()
+{
+	static  int init = 1;
+
+	if (init)
+	{
+		UCHAR    *p;
+#ifdef  WIN32
+		char    pathname[_MAX_PATH];
+
+		if (GetModuleFileName(NULL, pathname, sizeof(pathname)) > 0)
+		_splitpath(pathname, NULL, NULL, exename, NULL);
+#else
+		CSTR flist[] = {"/proc/self/exe", "/proc/curproc/file", "/proc/curproc/exe" };
+		int     i;
+		char    path_name[256];
+
+		for (i = 0; i < sizeof(flist) / sizeof(flist[0]); i++)
+		{
+			if (readlink(flist[i], path_name, sizeof(path_name)) > 0)
+			{
+				/* fprintf(stderr, "i=%d pathname=%s\n", i, path_name); */
+				STRCPY_FIXED(exename, po_basename(path_name));
+				break;
+			}
+		}
+#endif /* WIN32 */
+		for (p = (UCHAR *) exename; '\0' != *p; p++)
+		{
+			if (isalnum(*p))
+				continue;
+			switch (*p)
+			{
+				case '_':
+				case '-':
+					continue;
+			}
+			*p = '\0';      /* avoid multi bytes for safety */
+			break;
+		}
+		init = 0;
+	}
+	return exename;
+}
+
 #if defined(WIN_MULTITHREAD_SUPPORT)
 static	CRITICAL_SECTION	qlog_cs, mylog_cs;
 #elif defined(POSIX_MULTITHREAD_SUPPORT)
@@ -162,6 +219,15 @@ int	get_qlog(void)
 	return qlog_on;
 }
 
+const char *po_basename(const char *path)
+{
+	char *p;
+
+	if (p = strrchr(path,  DIRSEPARATOR[0]), NULL != p)
+		return p + 1;
+	return path;
+}
+
 void
 logs_on_off(int cnopen, int mylog_onoff, int qlog_onoff)
 {
@@ -171,7 +237,6 @@ logs_on_off(int cnopen, int mylog_onoff, int qlog_onoff)
 			qlog_off_count = 0;
 
 	ENTER_MYLOG_CS;
-	ENTER_QLOG_CS;
 	if (mylog_onoff)
 		mylog_on_count += cnopen;
 	else
@@ -187,18 +252,26 @@ logs_on_off(int cnopen, int mylog_onoff, int qlog_onoff)
 		mylog_on = 0;
 	else if (getGlobalDebug() > 0)
 		mylog_on = getGlobalDebug();
+	LEAVE_MYLOG_CS;
+
+	ENTER_QLOG_CS;
 	if (qlog_onoff)
 		qlog_on_count += cnopen;
 	else
 		qlog_off_count += cnopen;
 	if (qlog_on_count > 0)
-		qlog_on = 1;
+	{
+		if (qlog_onoff > qlog_on)
+			qlog_on = qlog_onoff;
+		else if (qlog_on < 1)
+			qlog_on = 1;
+	}
 	else if (qlog_off_count > 0)
 		qlog_on = 0;
 	else if (getGlobalCommlog() > 0)
 		qlog_on = getGlobalCommlog();
 	LEAVE_QLOG_CS;
-	LEAVE_MYLOG_CS;
+MYLOG(0, "mylog_on=%d qlog_on=%d\n", mylog_on, qlog_on);
 }
 
 #ifdef	WIN32
@@ -237,13 +310,12 @@ static void MLOG_open()
 	}
 }
 
-DLL_DECLARE void
-mylog(const char *fmt,...)
+static int
+mylog_misc(unsigned int option, const char *fmt, va_list args)
 {
-	va_list		args;
+	// va_list		args;
 	int		gerrno;
-
-	if (!mylog_on)	return;
+	BOOL	log_threadid = option;
 
 	gerrno = GENERAL_ERRNO;
 	ENTER_MYLOG_CS;
@@ -251,7 +323,7 @@ mylog(const char *fmt,...)
 	if (!start_time)
 		start_time = timeGetTime();
 #endif /* LOGGING_PROCESS_TIME */
-	va_start(args, fmt);
+	// va_start(args, fmt);
 
 	if (!MLOGFP)
 	{
@@ -262,6 +334,8 @@ mylog(const char *fmt,...)
 
 	if (MLOGFP)
 	{
+		if (log_threadid)
+		{
 #ifdef	WIN_MULTITHREAD_SUPPORT
 #ifdef	LOGGING_PROCESS_TIME
 		DWORD	proc_time = timeGetTime() - start_time;
@@ -271,15 +345,46 @@ mylog(const char *fmt,...)
 #endif /* LOGGING_PROCESS_TIME */
 #endif /* WIN_MULTITHREAD_SUPPORT */
 #if defined(POSIX_MULTITHREAD_SUPPORT)
-		fprintf(MLOGFP, "[%lu]", pthread_self());
+		fprintf(MLOGFP, "[%lx]", (unsigned long int) pthread_self());
 #endif /* POSIX_MULTITHREAD_SUPPORT */
+		}
 		vfprintf(MLOGFP, fmt, args);
 	}
 
-	va_end(args);
+	// va_end(args);
 	LEAVE_MYLOG_CS;
 	GENERAL_ERRNO_SET(gerrno);
+
+	return 1;
 }
+
+DLL_DECLARE int
+mylog(const char *fmt,...)
+{
+	int	ret = 0;
+	unsigned int option = 1;
+	va_list	args;
+
+	if (!mylog_on)	return ret;
+
+	va_start(args, fmt);
+	ret = mylog_misc(option, fmt, args);
+	va_end(args);
+	return	ret;
+}
+
+DLL_DECLARE int
+myprintf(const char *fmt,...)
+{
+	int	ret = 0;
+	va_list	args;
+
+	va_start(args, fmt);
+	ret = mylog_misc(0, fmt, args);
+	va_end(args);
+	return	ret;
+}
+
 static void mylog_initialize(void)
 {
 	INIT_MYLOG_CS;
@@ -297,14 +402,14 @@ static void mylog_finalize(void)
 
 
 static FILE *QLOGFP = NULL;
-void
-qlog(char *fmt,...)
+
+static int
+qlog_misc(unsigned int option, const char *fmt, va_list args)
 {
-	va_list		args;
 	char		filebuf[80];
 	int		gerrno;
 
-	if (!qlog_on)	return;
+	if (!qlog_on)	return 0;
 
 	gerrno = GENERAL_ERRNO;
 	ENTER_QLOG_CS;
@@ -312,7 +417,6 @@ qlog(char *fmt,...)
 	if (!start_time)
 		start_time = timeGetTime();
 #endif /* LOGGING_PROCESS_TIME */
-	va_start(args, fmt);
 
 	if (!QLOGFP)
 	{
@@ -331,17 +435,47 @@ qlog(char *fmt,...)
 
 	if (QLOGFP)
 	{
+		if (option)
+		{
 #ifdef	LOGGING_PROCESS_TIME
 		DWORD	proc_time = timeGetTime() - start_time;
 		fprintf(QLOGFP, "[%d.%03d]", proc_time / 1000, proc_time % 1000);
 #endif /* LOGGING_PROCESS_TIME */
+		}
 		vfprintf(QLOGFP, fmt, args);
 	}
 
-	va_end(args);
 	LEAVE_QLOG_CS;
 	GENERAL_ERRNO_SET(gerrno);
+
+	return 1;
 }
+int
+qlog(char *fmt,...)
+{
+	int	ret = 0;
+	unsigned int option = 1;
+	va_list	args;
+
+	if (!qlog_on)	return ret;
+
+	va_start(args, fmt);
+	ret = qlog_misc(option, fmt, args);
+	va_end(args);
+	return	ret;
+}
+int
+qprintf(char *fmt,...)
+{
+	int	ret = 0;
+	va_list	args;
+
+	va_start(args, fmt);
+	ret = qlog_misc(0, fmt, args);
+	va_end(args);
+	return	ret;
+}
+
 static void qlog_initialize(void)
 {
 	INIT_QLOG_CS;
