@@ -41,9 +41,24 @@
 #include <stdlib.h>
 #endif /* WIN32 */
 
-#ifndef	__GNUC__
+#ifdef  __INCLUDE_POSTGRES_FE_H__ /* currently not defined */
+/*
+ *      Unfortunately #including postgres_fe.h causes various trobles.
+ */
+#include "postgres_fe.h"
+#else /* currently */
+#if defined(__GNUC__) || defined(__IBMC__)
+#if ((__GNUC__ * 100) + __GNUC_MINOR__) >= 404
+#define PG_PRINTF_ATTRIBUTE gnu_printf
+#else
+#define PG_PRINTF_ATTRIBUTE printf
+#endif
+#define pg_attribute_printf(f,a) __attribute__((format(PG_PRINTF_ATTRIBUTE, f, a)))
+#else
 #define	__attribute__(x)
-#endif /* __GNUC__ */
+#define pg_attribute_printf(f,a)
+#endif  /* __GNUC__ || __IBMC__ */
+#endif  /* __INCLUDE_POSTGRES_FE_H__ */
 
 #ifdef	_MEMORY_DEBUG_
 void		*pgdebug_alloc(size_t);
@@ -246,13 +261,12 @@ typedef double SDOUBLE;
 #define	FALSE	(BOOL)0
 #endif /* FALSE */
 #else
+
 #if (_MSC_VER < 1900) /* vc12 or under */
 #define POSIX_SNPRINTF_REQUIRED
 #define snprintf posix_snprintf
 extern int posix_snprintf(char *buf, size_t size, const char *format, ...);
 #endif /* _MSC_VER */
-
-
 #ifndef strdup
 #define strdup _strdup
 #endif /* strdup */
@@ -260,6 +274,8 @@ extern int posix_snprintf(char *buf, size_t size, const char *format, ...);
 #define stricmp _stricmp
 #endif /* WIN32 */
 
+#define IS_NOT_SPACE(c) ((c) && !isspace((UCHAR) c))
+
 #ifndef	SQL_ATTR_APP_ROW_DESC
 #define	SQL_ATTR_APP_ROW_DESC	10010
 #endif
