@@ -110,6 +110,8 @@
 #define ID2NDPAGE			1102
 #define ID3RDPAGE			1103
 #define DS_LIBPQOPT			1104
+#define DS_COMMLOG			1105
+#define DS_DEBUG			1106
 
 // Next default values for new objects
 //
@@ -117,7 +119,7 @@
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_NEXT_RESOURCE_VALUE        106
 #define _APS_NEXT_COMMAND_VALUE         40001
-#define _APS_NEXT_CONTROL_VALUE         1105
+#define _APS_NEXT_CONTROL_VALUE         1107
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
 #endif
