@@ -105,20 +105,21 @@ enum
 	STMT_TYPE_UNKNOWN = -2
 	,STMT_TYPE_OTHER = -1
 	,STMT_TYPE_SELECT = 0
+	,STMT_TYPE_WITH
+	,STMT_TYPE_PROCCALL
+	,STMT_TYPE_TRANSACTION
+	,STMT_TYPE_DECLARE
+	,STMT_TYPE_FETCH
+	,STMT_TYPE_CLOSE
 	,STMT_TYPE_INSERT
 	,STMT_TYPE_UPDATE
 	,STMT_TYPE_DELETE
-	,STMT_TYPE_WITH
 	,STMT_TYPE_CREATE
 	,STMT_TYPE_ALTER
 	,STMT_TYPE_DROP
 	,STMT_TYPE_GRANT
 	,STMT_TYPE_REVOKE
-	,STMT_TYPE_PROCCALL
 	,STMT_TYPE_LOCK
-	,STMT_TYPE_TRANSACTION
-	,STMT_TYPE_CLOSE
-	,STMT_TYPE_FETCH
 	,STMT_TYPE_PREPARE
 	,STMT_TYPE_EXECUTE
 	,STMT_TYPE_DEALLOCATE
@@ -127,14 +128,13 @@ enum
 	,STMT_TYPE_EXPLAIN
 	,STMT_TYPE_SET
 	,STMT_TYPE_RESET
-	,STMT_TYPE_DECLARE
 	,STMT_TYPE_MOVE
 	,STMT_TYPE_COPY
 	,STMT_TYPE_START
 	,STMT_TYPE_SPECIAL
 };
 
-#define STMT_UPDATE(stmt)	((stmt)->statement_type > STMT_TYPE_SELECT)
+#define STMT_UPDATE(stmt)	((stmt)->statement_type > STMT_TYPE_PROCCALL)
 
 
 /*	Parsing status */
