@@ -31,6 +31,24 @@ print_diag(char *msg, SQLSMALLINT htype, SQLHANDLE handle)
 		printf("No error information\n");
 }
 
+const char * const default_dsn = "psqlodbc_test_dsn";
+const char * const test_dsn_env = "PSQLODBC_TEST_DSN";
+const char * const test_dsn_ansi = "psqlodbc_test_dsn_ansi";
+
+const char *get_test_dsn(void)
+{
+	char	*env = getenv(test_dsn_env);
+
+	if (NULL != env && env[0])
+		return env;
+	return default_dsn;
+}
+
+int IsAnsi(void)
+{
+	return (strcmp(get_test_dsn(), test_dsn_ansi) == 0);
+}
+
 void
 test_connect_ext(char *extraparams)
 {
@@ -38,9 +56,33 @@ test_connect_ext(char *extraparams)
 	SQLCHAR str[1024];
 	SQLSMALLINT strl;
 	SQLCHAR dsn[1024];
+	const char * const test_dsn = get_test_dsn();
+	char *envvar;
 
-	snprintf(dsn, sizeof(dsn), "DSN=psqlodbc_test_dsn;%s",
-			 extraparams ? extraparams : "");
+	/*
+	 *	Use an environment variable to switch settings of connection
+	 *	strings throughout the regression test. Note that extraparams
+	 *	parameters have precedence over the environment variable.
+	 *	ODBC spec says
+	 *		If any keywords are repeated in the connection string,
+	 *		the driver uses the value associated with the first
+	 *		occurrence of the keyword.
+	 *	But the current psqlodbc driver uses the value associated with
+	 *	the last occurrence of the keyword. Here we place extraparams
+	 *	both before and after the value of the environment variable
+	 *	so as to protect the priority order whichever way we take.
+	 */
+	if ((envvar = getenv("COMMON_CONNECTION_STRING_FOR_REGRESSION_TEST")) != NULL && envvar[0] != '\0')
+	{
+		if (NULL == extraparams)
+			snprintf(dsn, sizeof(dsn), "DSN=%s;%s", test_dsn, envvar);
+		else
+			snprintf(dsn, sizeof(dsn), "DSN=%s;%s;%s;%s",
+			 test_dsn, extraparams, envvar, extraparams);
+	}
+	else
+		snprintf(dsn, sizeof(dsn), "DSN=%s;%s",
+			 test_dsn, extraparams ? extraparams : "");
 
 	SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &env);
 
